Crate vaultarq

Crate vaultarq 

vaultarq

A Rust SDK for the Vaultarq secrets manager that seamlessly integrates with Rust applications by automatically loading secrets from a Vaultarq vault and injecting them into the environment.

Basic Usage

use vaultarq::init;

fn main() {
    // Load secrets into environment variables
    init().unwrap();

    // Now use secrets from environment
    println!("API_KEY: {}", std::env::var("API_KEY").unwrap_or_default());
}

Structs

Config
Configuration for loading secrets.

Enums

Error
Errors that can occur when using the Vaultarq SDK.
Format
Format for exporting secrets.

Functions

init
Load secrets from Vaultarq into environment variables using default configuration.
init_with_config
Load secrets from Vaultarq into environment variables using custom configuration.
is_available
Check if Vaultarq is installed and accessible.
is_available_with_path
Check if Vaultarq is installed and accessible at the specified path.